function [deltax,x1,x2]=oscdeltax2(OscRecord,wfm1,y1,wfm2,y2,shouldPlot=false)

# [deltax, x1, x2] = oscdeltax2(OscRecord, wfm1, y1, wfm2, y2, shouldPlot)
#
# Calculates the distance on the X-axis between a point x1 where the waveform 
# wfm1 (as contained in the structure OscRecord) first crosses the level y1 and 
# a point x2 where the waveform wfm2 subsequently crosses the level y2. This 
# distance deltax is calculated as
#
#   deltax = x2 - x1
# 
# If the optional parameter shouldPlot is true, then the operation is illustrated 
# in a graph with two sub-plots, with the first one visualises the point (x1, y1) 
# on the waveform wfm1 and the second one, the point (x2, y2) on the waveform 
# wfm2.
#
# If wfm* is a number, it is treated as the index of the respective waveform 
# within OscRecord. Otherwise, it is treated as its label as set in the 
# oscilloscope.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  if (!isnumeric(wfm1))
    wfm1 = oscwfmidx(OscRecord, wfm1);
  endif
  if (!isnumeric(wfm2))
    wfm2 = oscwfmidx(OscRecord, wfm2);
  endif
  
  [i1,x1] = oscsearchy(OscRecord.Waveforms(wfm1), y1);
  [i2,x2] = oscsearchy(OscRecord.Waveforms(wfm2), y2, x1);
  deltax = x2-x1;
  
  if (shouldPlot)
    ys = [y1 y2];
    xs = [x1 x2];
    wfms = [wfm1 wfm2];
    figure();
    for iWfm = [1:2]    
      hax=subplot(2,1,iWfm);
      oscplotwfm(OscRecord, wfms(iWfm), 0, 1, 0, "xy");
      hold on;
      xLims = get(hax, "xlim");
      plot(xLims, [ys(iWfm) ys(iWfm)], ":r");
      yLims = get(hax, "ylim");
      plot([x1 x1], yLims, ":r");
      plot([x2 x2], yLims, ":r");
      plot(xs(iWfm), ys(iWfm), "+r", "markersize", 8, "linewidth", 2);
      hold off;
    endfor
  endif
  
endfunction
