function oscplotwfm(OscRecord,wfm,toffset=0,ymult=1,yoffset=0,labels=[],label="")

# oscplotwfm(OscRecord, wfm, toffset, ymult, yoffset, labels, label)
#
# Plots the waveform indentified by wfm against time as contained in the 
# structure OscRecord.
#
# If wfm is a number, it is treated as the index of the respective waveform 
# within OscRecord. Otherwise, it is treated as its label as set in the 
# oscilloscope.
#
# The optional parameter toffset (defaulting to 0) enables the waveform to be 
# shifted with respect to the time (X) axis.
#
# The values of the waveform can be multiplied by ymult (defaulting to 1) and 
# then shifted by yoffset (defaulting to 0).
#
# If the optional parameter labels is provided, it defines how axes and the 
# waveform are labelled:
#   - "xy" -- the value of xUnit from OscRecord is used as the X-axis label and 
#       the waveform label is used as the Y-axis label
#   - "xl" -- the value of xUnit from OscRecord is used as the X-axis label and 
#       the waveform label is used as its legend
#
# If the optional parameter label is provided, it overrides the waveform label 
# found in OscRecord.
#
# For a description of OscRecord, see oscreadtbs().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  if (!isnumeric(wfm))
    wfm = oscwfmidx(OscRecord, wfm);
  endif
  
  Params = OscRecord.Waveforms(wfm).Params;
  
  if (strcmp(label,""))
    wfmLabel = Params.label;
    if (yoffset != 0)
      if (yoffset > 0)
        yoffsetSign = " + "
      else
        yoffsetSign = " - ";
      endif
      if (isfield(Params,"yUnit"))
        wfmLabel = cstrcat("(", wfmLabel);
      endif
    endif
    if (ymult != 1)
      wfmLabel = cstrcat(num2str(ymult), " * ", wfmLabel);
    endif
    if (yoffset != 0)
      wfmLabel = cstrcat(wfmLabel, yoffsetSign, num2str(abs(yoffset)));
      if (isfield(Params,"yUnit"))
        wfmLabel = cstrcat(wfmLabel, ")");
      endif
    endif
    if (isfield(Params,"yUnit"))
      wfmLabel = cstrcat(wfmLabel, " / ", Params.yUnit);
    endif
  else
    wfmLabel = label;
  endif
  fmt = "";
  if (strcmp(labels,"xl"))
    fmt = strcat(";", wfmLabel, ";");
  endif
  
  plot(OscRecord.Waveforms(wfm).Values.x+toffset, ...
    ymult*OscRecord.Waveforms(wfm).Values.y+yoffset, fmt);
  grid on;
  
  switch (labels)
    case "xy"
      if (isfield(Params,"xUnit"))
        xlabel(Params.xUnit);
      endif
      ylabel(wfmLabel);
    case "xl"
      if (isfield(Params,"xUnit"))
        xlabel(Params.xUnit);
      endif
  endswitch
  
endfunction
