function yflt=wavglinn(y,nWeights=1)
  
# yflt = wavglinn(y, nWeights)
#
# Performs a running weighted average filtering of y using a linear weight 
# function.
#
# The number of points used for averaging on either side of every point in y 
# is defined by nWeights (defaulting to 1). Thus,
# 
#                j+nWeights
#     yflt(j) =     sum      y(k) * w(|k-j|) / sum(w)
#               k=j-nWeights
#
#     w(n) = 1 - n/(nWeights+1)
#
# Note that w is always non-zero, with w(0) = 1 and 
# w(nWeights) = 1/(nWeights+1).

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  weights = ones(1,2*nWeights+1);
  for iSample = [1:nWeights]
    weight = 1-iSample/(nWeights+1);
    weights(nWeights+1+iSample) = weight;
    weights(nWeights+1-iSample) = weight;
  endfor
  weightsSum = sum(weights);
  
  nSamples = numel(y);
  yflt = zeros(1, nSamples);
  for iSample = [1:nSamples]
    if ((iSample-nWeights >= 1) && (iSample+nWeights <= nSamples))
      yflt(iSample) = sum(y((iSample-nWeights):(iSample+nWeights)) .* weights) / weightsSum;
    else
      nSamplesLeft = iSample-max(iSample-nWeights, 1);
      nSamplesRight = min(iSample+nWeights, nSamples)-iSample;
      ySel = y((iSample-nSamplesLeft):(iSample+nSamplesRight));
      weightsSel = weights((nWeights+1-nSamplesLeft):(nWeights+1+nSamplesRight));
      yflt(iSample) = sum(ySel .* weightsSel) / sum(weightsSel);
    endif
  endfor
  
endfunction
